API Reference
=============

This section contains the complete API reference for Serilux.

Core Classes
------------

.. toctree::
   :maxdepth: 2

   serializable

Functions
---------

.. automodule:: serilux
   :members:
   :undoc-members:
   :show-inheritance:

